//                              driver.h

#ifndefH_driver_
#defineH_driver_

/*
   $Id: driver.h 224 2008-03-19 15:16:28Z fbb $

   $Log$
   Revision 1.1  2005/11/11 14:22:42  frank
   Added local* classes, randstream randbuffer and mailheaders

   Revision 1.1.1.1  2003/05/31 13:17:04  frank
   Initial import of Randbuffer

   Revision 1.1.1.1  2003/05/31 12:41:09  frank
   Initial import of Randbuffer

*/

//#include <iosfwd>
//#include <iostream>
//#include <fstream>
//#include <string>
//#include <sstream>

//using namespace std;

#endif
